# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_course_simple import ResponseWrapperCourseSimple

class TestResponseWrapperCourseSimple(unittest.TestCase):
    """ResponseWrapperCourseSimple unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperCourseSimple:
        """Test ResponseWrapperCourseSimple
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperCourseSimple`
        """
        model = ResponseWrapperCourseSimple()
        if include_optional:
            return ResponseWrapperCourseSimple(
                done = True,
                result = public_api_server_connector_v2.models.course_simple.CourseSimple(
                    title = '', 
                    image_id = '', 
                    description = '', 
                    url = '', 
                    payload = '', 
                    module_view_type = null, 
                    payment_type = null, 
                    course_access_type = null, 
                    number_days_access = 56, 
                    is_active = True, 
                    is_secret = True, 
                    is_archived = True, 
                    is_displayed_in_app = True, 
                    is_offline_downloadable = True, 
                    available_at = 56, 
                    launch_date_enabled = True, 
                    launch_date = 56, 
                    id = 56, 
                    portal_id = 56, 
                    order = 56, 
                    category = '', 
                    category_id = 56, 
                    sales_page_landing_id = 56, 
                    permalink = '', 
                    enable_double_optin = True, 
                    one_more_landing_id = 56, 
                    one_more_step_link = '', 
                    one_more_step_landing_id = 56, 
                    created_at_epoch = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperCourseSimple(
                done = True,
        )
        """

    def testResponseWrapperCourseSimple(self):
        """Test ResponseWrapperCourseSimple"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.file_upload_result import FileUploadResult
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ResponseWrapperFileUploadResult(BaseModel):
    """
    ResponseWrapperFileUploadResult
    """ # noqa: E501
    done: StrictBool = Field(description="Indicates if the operation was successful. True if successful, False otherwise. Always matches the HTTP status code. 2xx for success, 4xx or 5xx for failure.")
    result: Optional[FileUploadResult] = Field(default=None, description="The result of the operation, if successful. Should be an instance of the specified model. If the operation failed, this will always be null.")
    error: Optional[StrictStr] = Field(default=None, description="Error message if the operation failed. Should be a string describing the error. If the operation was successful, this will always be null.")
    __properties: ClassVar[List[str]] = ["done", "result", "error"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResponseWrapperFileUploadResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResponseWrapperFileUploadResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "done": obj.get("done"),
            "result": FileUploadResult.from_dict(obj["result"]) if obj.get("result") is not None else None,
            "error": obj.get("error")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.general_api import GeneralApi


class TestGeneralApi(unittest.IsolatedAsyncioTestCase):
    """GeneralApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = GeneralApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_key_auth_get_api_key_info(self) -> None:
        """Test case for api_key_auth_get_api_key_info

        Get Api Key Info
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.courses_api import CoursesApi


class TestCoursesApi(unittest.IsolatedAsyncioTestCase):
    """CoursesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CoursesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_key_auth_add_course(self) -> None:
        """Test case for api_key_auth_add_course

        Add Course
        """
        pass

    async def test_api_key_auth_add_course_module(self) -> None:
        """Test case for api_key_auth_add_course_module

        Add Course Module
        """
        pass

    async def test_api_key_auth_add_course_module_lessons(self) -> None:
        """Test case for api_key_auth_add_course_module_lessons

        Add Course Module Lessons
        """
        pass

    async def test_api_key_auth_add_module_submodule(self) -> None:
        """Test case for api_key_auth_add_module_submodule

        Add Module Submodule
        """
        pass

    async def test_api_key_auth_count_courses(self) -> None:
        """Test case for api_key_auth_count_courses

        Count Courses
        """
        pass

    async def test_api_key_auth_delete_course(self) -> None:
        """Test case for api_key_auth_delete_course

        Delete Course
        """
        pass

    async def test_api_key_auth_delete_course_module(self) -> None:
        """Test case for api_key_auth_delete_course_module

        Delete Course Module
        """
        pass

    async def test_api_key_auth_delete_course_module_lesson(self) -> None:
        """Test case for api_key_auth_delete_course_module_lesson

        Delete Course Module Lesson
        """
        pass

    async def test_api_key_auth_delete_module_submodule(self) -> None:
        """Test case for api_key_auth_delete_module_submodule

        Delete Module Submodule
        """
        pass

    async def test_api_key_auth_get_course(self) -> None:
        """Test case for api_key_auth_get_course

        Get Course
        """
        pass

    async def test_api_key_auth_get_course_info(self) -> None:
        """Test case for api_key_auth_get_course_info

        Get Course Info
        """
        pass

    async def test_api_key_auth_get_course_module(self) -> None:
        """Test case for api_key_auth_get_course_module

        Get Course Module
        """
        pass

    async def test_api_key_auth_get_course_module_count(self) -> None:
        """Test case for api_key_auth_get_course_module_count

        Get Course Module Count
        """
        pass

    async def test_api_key_auth_get_course_module_info(self) -> None:
        """Test case for api_key_auth_get_course_module_info

        Get Course Module Info
        """
        pass

    async def test_api_key_auth_get_course_module_lesson(self) -> None:
        """Test case for api_key_auth_get_course_module_lesson

        Get Course Module Lesson
        """
        pass

    async def test_api_key_auth_get_course_module_lesson_content_blocks(self) -> None:
        """Test case for api_key_auth_get_course_module_lesson_content_blocks

        Get Course Module Lesson Content Blocks
        """
        pass

    async def test_api_key_auth_get_course_module_lesson_info(self) -> None:
        """Test case for api_key_auth_get_course_module_lesson_info

        Get Course Module Lesson Info
        """
        pass

    async def test_api_key_auth_get_course_module_lessons(self) -> None:
        """Test case for api_key_auth_get_course_module_lessons

        Get Course Module Lessons
        """
        pass

    async def test_api_key_auth_get_course_module_lessons_count(self) -> None:
        """Test case for api_key_auth_get_course_module_lessons_count

        Get Course Module Lessons Count
        """
        pass

    async def test_api_key_auth_get_course_modules(self) -> None:
        """Test case for api_key_auth_get_course_modules

        Get Course Modules
        """
        pass

    async def test_api_key_auth_get_courses(self) -> None:
        """Test case for api_key_auth_get_courses

        Get Courses
        """
        pass

    async def test_api_key_auth_get_module_submodule_count(self) -> None:
        """Test case for api_key_auth_get_module_submodule_count

        Get Module Submodule Count
        """
        pass

    async def test_api_key_auth_get_module_submodules(self) -> None:
        """Test case for api_key_auth_get_module_submodules

        Get Module Submodules
        """
        pass

    async def test_api_key_auth_get_submodule(self) -> None:
        """Test case for api_key_auth_get_submodule

        Get Submodule
        """
        pass

    async def test_api_key_auth_patch_course(self) -> None:
        """Test case for api_key_auth_patch_course

        Patch Course
        """
        pass

    async def test_api_key_auth_patch_course_module(self) -> None:
        """Test case for api_key_auth_patch_course_module

        Patch Course Module
        """
        pass

    async def test_api_key_auth_patch_course_module_lesson(self) -> None:
        """Test case for api_key_auth_patch_course_module_lesson

        Patch Course Module Lesson
        """
        pass

    async def test_api_key_auth_patch_course_module_lesson_attached_files(self) -> None:
        """Test case for api_key_auth_patch_course_module_lesson_attached_files

        Patch Course Module Lesson Attached Files
        """
        pass

    async def test_api_key_auth_patch_course_module_lesson_content_blocks(self) -> None:
        """Test case for api_key_auth_patch_course_module_lesson_content_blocks

        Patch Course Module Lesson Content Blocks
        """
        pass

    async def test_api_key_auth_patch_module_submodule(self) -> None:
        """Test case for api_key_auth_patch_module_submodule

        Patch Module Submodule
        """
        pass

    async def test_api_key_auth_update_course(self) -> None:
        """Test case for api_key_auth_update_course

        Update Course
        """
        pass

    async def test_api_key_auth_update_course_module(self) -> None:
        """Test case for api_key_auth_update_course_module

        Update Course Module
        """
        pass

    async def test_api_key_auth_update_course_module_lesson(self) -> None:
        """Test case for api_key_auth_update_course_module_lesson

        Update Course Module Lesson
        """
        pass

    async def test_api_key_auth_update_module_submodule(self) -> None:
        """Test case for api_key_auth_update_module_submodule

        Update Module Submodule
        """
        pass


if __name__ == '__main__':
    unittest.main()
